@@ -4,8 +4,8 @@ package WWW::Sitemapper::Types;
 BEGIN {
   $WWW::Sitemapper::Types::AUTHORITY = 'cpan:AJGB';
 }
-BEGIN {
-  $WWW::Sitemapper::Types::VERSION = '1.110340';
+{
+  $WWW::Sitemapper::Types::VERSION = '1.121160';
 }
 #ABSTRACT: Types used by L<WWW::Sitemapper>.
 
@@ -62,7 +62,7 @@ WWW::Sitemapper::Types - Types used by L<WWW::Sitemapper>.
 
 =head1 VERSION
 
-version 1.110340
+version 1.121160
 
 =head1 SYNOPSIS
 
@@ -108,11 +108,13 @@ Coerces from C<Num> via L<DateTime::Duration>-E<gt>new( minutes => $_ ).
 
 =head1 SEE ALSO
 
+Please see those modules/websites for more information related to this module.
+
 =over 4
 
 =item *
 
-L<WWW::Sitemapper>
+L<WWW::Sitemapper|WWW::Sitemapper>
 
 =back
 
@@ -122,7 +124,7 @@ Alex J. G. Burzyński <ajgb@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Alex J. G. Burzyński <ajgb@cpan.org>.
+This software is copyright (c) 2012 by Alex J. G. Burzyński <ajgb@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
